Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/indium/__init__.py | (no class) | 9 | 0 | 0 | 100%
src/indium/_confusables.py | (no class) | 2 | 0 | 0 | 100%
src/indium/_exceptions.py | IndiumError | 0 | 0 | 0 | 100%
src/indium/_exceptions.py | InvalidTextError | 2 | 0 | 0 | 100%
src/indium/_exceptions.py | TruncationError | 0 | 0 | 0 | 100%
src/indium/_exceptions.py | (no class) | 7 | 0 | 0 | 100%
src/indium/_grapheme_data.py | (no class) | 21 | 0 | 0 | 100%
src/indium/_scripts_data.py | (no class) | 2 | 0 | 0 | 100%
src/indium/_unicode_data.py | (no class) | 30 | 2 | 0 | 93%
src/indium/invisibles.py | (no class) | 50 | 0 | 0 | 100%
src/indium/segments.py | (no class) | 135 | 2 | 0 | 99%
src/indium/spoofing.py | (no class) | 72 | 4 | 0 | 94%
Total |  | 330 | 8 | 0 | 98%

No items found using the specified filter.